@@ -30,11 +30,13 @@
 #include <QFileInfo>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <KCrash>
 
 int main(int argc, char **argv)
 {
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication a(argc, argv);
-
+    KCrash::initialize();
     KLocalizedString::setApplicationDomain("kwalletmanager");
 
     /**
@@ -49,7 +51,7 @@ int main(int argc, char **argv)
                  QStringLiteral(KWALLETMANAGER_VERSION_STRING),
                  i18n("KDE Wallet Management Tool"),
                  KAboutLicense::GPL,
-                 i18n("Copyright ©2013–2015, KWallet Manager authors"),
+                 i18n("Copyright ©2013–2017, KWallet Manager authors"),
                  QString(),
                  QStringLiteral("http://utils.kde.org/projects/kwalletmanager"));
 
@@ -76,19 +78,19 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.addVersionOption();
 
-    parser.addOption(QCommandLineOption("show", i18n("Show window on startup")));
-    parser.addOption(QCommandLineOption("kwalletd", i18n("For use by kwalletd only")));
-    parser.addOption(QCommandLineOption("name", i18n("A wallet name")));
+    parser.addOption(QCommandLineOption(QStringLiteral("show"), i18n("Show window on startup")));
+    parser.addOption(QCommandLineOption(QStringLiteral("kwalletd"), i18n("For use by kwalletd only")));
+    parser.addOption(QCommandLineOption(QStringLiteral("name"), i18n("A wallet name")));
 
     parser.process(a);
     KWalletManager wm;
     QObject::connect(&dbssvc, &KDBusService::activateRequested, &wm, &QWidget::activateWindow);
 
-    if (parser.isSet("show")) {
+    if (parser.isSet(QStringLiteral("show"))) {
         wm.show();
     }
 
-    if (parser.isSet("kwalletd")) {
+    if (parser.isSet(QStringLiteral("kwalletd"))) {
         wm.kwalletdLaunch();
     }
 
@@ -99,7 +101,7 @@ int main(int argc, char **argv)
             QMimeDatabase mimeDb;
             QMimeType mt = mimeDb.mimeTypeForFile(fn, QMimeDatabase::MatchContent);
 
-            if (mt.isValid() && mt.inherits(QLatin1String("application/x-kwallet"))) {
+            if (mt.isValid() && mt.inherits(QStringLiteral("application/x-kwallet"))) {
                 wm.openWalletFile(fn);
             }
         } else {
